@@ -30,7 +30,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: eeprom.h,v 1.21.2.13 2009/12/03 18:38:59 arcanum Exp $ */
+/* $Id: eeprom.h 2211 2011-02-14 14:04:25Z aboyapati $ */
 
 #ifndef _AVR_EEPROM_H_
 #define _AVR_EEPROM_H_ 1
@@ -173,10 +173,14 @@
 # define _EEPROM_SUFFIX  _m324pa
 #elif defined (__AVR_ATmega325__)
 # define _EEPROM_SUFFIX  _m325
+#elif defined (__AVR_ATmega325A__)
+# define _EEPROM_SUFFIX  _m325a
 #elif defined (__AVR_ATmega325P__)
 # define _EEPROM_SUFFIX  _m325p
 #elif defined (__AVR_ATmega3250__)
 # define _EEPROM_SUFFIX  _m3250
+#elif defined (__AVR_ATmega3250A__)
+# define _EEPROM_SUFFIX  _m3250a
 #elif defined (__AVR_ATmega3250P__)
 # define _EEPROM_SUFFIX  _m3250p
 #elif defined (__AVR_ATmega328__)
@@ -185,16 +189,22 @@
 # define _EEPROM_SUFFIX  _m328p
 #elif defined (__AVR_ATmega329__)
 # define _EEPROM_SUFFIX  _m329
+#elif defined (__AVR_ATmega329A__)
+# define _EEPROM_SUFFIX  _m329a
 #elif defined (__AVR_ATmega329P__)
 # define _EEPROM_SUFFIX  _m329p
 #elif defined (__AVR_ATmega329PA__)
 # define _EEPROM_SUFFIX  _m329pa
 #elif defined (__AVR_ATmega3290__)
 # define _EEPROM_SUFFIX  _m3290
+#elif defined (__AVR_ATmega3290A__)
+# define _EEPROM_SUFFIX  _m3290a
 #elif defined (__AVR_ATmega3290P__)
 # define _EEPROM_SUFFIX  _m3290p
 #elif defined (__AVR_ATmega32HVB__)
 # define _EEPROM_SUFFIX  _m32hvb
+#elif defined (__AVR_ATmega32HVBREVB__)
+# define _EEPROM_SUFFIX  _m32hvbrevb
 #elif defined (__AVR_ATmega64HVE__)
 # define _EEPROM_SUFFIX  _m64hve
 #elif defined (__AVR_ATmega406__)
@@ -241,6 +251,8 @@
 # define _EEPROM_SUFFIX  _m16hva2
 #elif defined (__AVR_ATmega16HVB__)
 # define _EEPROM_SUFFIX  _m16hvb
+#elif defined (__AVR_ATmega16HVBREVB__)
+# define _EEPROM_SUFFIX  _m16hvbrevb
 #elif defined (__AVR_ATmega8__)
 # define _EEPROM_SUFFIX  _m8
 #elif defined (__AVR_ATmega48__)
@@ -311,6 +323,8 @@
 # define _EEPROM_SUFFIX _tn44a
 #elif defined (__AVR_ATtiny84__)
 # define _EEPROM_SUFFIX _tn84
+#elif defined (__AVR_ATtiny84A__)
+# define _EEPROM_SUFFIX _tn84a
 #elif defined (__AVR_ATtiny261__)
 # define _EEPROM_SUFFIX _tn261
 #elif defined (__AVR_ATtiny261A__)
@@ -345,12 +359,16 @@
 # define _EEPROM_SUFFIX   _x32d4
 #elif defined (__AVR_ATxmega64A1__)
 # define _EEPROM_SUFFIX   _x64a1
+#elif defined (__AVR_ATxmega64A1U__)
+# define _EEPROM_SUFFIX   _x64a1u
 #elif defined (__AVR_ATxmega64A3__)
 # define _EEPROM_SUFFIX   _x64a3
 #elif defined (__AVR_ATxmega64D3__)
 # define _EEPROM_SUFFIX   _x64d3
 #elif defined (__AVR_ATxmega128A1__)
 # define _EEPROM_SUFFIX   _x128a1
+#elif defined (__AVR_ATxmega128A1U__)
+# define _EEPROM_SUFFIX   _x128a1u
 #elif defined (__AVR_ATxmega128A3__)
 # define _EEPROM_SUFFIX   _x128a3
 #elif defined (__AVR_ATxmega128D3__)
