@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom323.h,v 1.13.2.2 2008/01/06 20:10:44 arcanum Exp $ */
+/* $Id: iom323.h 1873 2009-02-11 17:53:39Z arcanum $ */
 
 /* avr/iom323.h - definitions for ATmega323 */
 
@@ -643,8 +643,9 @@
 /* Constants */
 #define SPM_PAGESIZE 128
 #define RAMEND		0x85F
-#define XRAMEND		0x85F
+#define XRAMEND		RAMEND
 #define E2END		0x3FF
+#define E2PAGESIZE  0
 #define FLASHEND	0x7FFF
 
 
@@ -653,22 +654,22 @@
 #define FUSE_MEMORY_SIZE 2
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_CKSEL2      ~_BV(2)
-#define FUSE_CKSEL3      ~_BV(3)
-#define FUSE_BODEN       ~_BV(6)
-#define FUSE_BODLEVEL    ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_BODEN       (unsigned char)~_BV(6)
+#define FUSE_BODLEVEL    (unsigned char)~_BV(7)
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3)
 
 /* High Fuse Byte */
-#define FUSE_BOOTRST     ~_BV(0)
-#define FUSE_BOOTSZ0     ~_BV(1)
-#define FUSE_BOOTSZ1     ~_BV(2)
-#define FUSE_EESAVE      ~_BV(3)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_JTAGEN      ~_BV(6)
-#define FUSE_OCDEN       ~_BV(7)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_JTAGEN      (unsigned char)~_BV(6)
+#define FUSE_OCDEN       (unsigned char)~_BV(7)
 #define HFUSE_DEFAULT (FUSE_SPIEN & FUSE_JTAGEN)
 
 
@@ -678,4 +679,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x95
+#define SIGNATURE_2 0x01
+
+
 #endif /* _AVR_IOM323_H_ */
