@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom32c1.h,v 1.1.2.8 2009/01/26 18:05:49 arcanum Exp $ */
+/* $Id: iom32c1.h 2183 2010-09-21 05:37:46Z aboyapati $ */
 
 /* avr/iom32c1.h - definitions for ATmega32C1 */
 
@@ -682,6 +682,7 @@
 
 #define DACON _SFR_MEM8(0x90)
 #define DAEN 0
+#define DAOE 1
 #define DALA 2
 #define DATS0 4
 #define DATS1 5
@@ -905,6 +906,9 @@
 
 #define CANIE1 _SFR_MEM8(0xDF)
 
+/* RegDef:  CAN Status Interrupt MOb Register*/
+#define CANSIT _SFR_MEM16(0xE0)
+
 #define CANSIT2 _SFR_MEM8(0xE0)
 #define SIT0 0
 #define SIT1 1
@@ -1053,6 +1057,9 @@
 #define CONMOB0 6
 #define CONMOB1 7
 
+/* RegDef:  CAN Identifier Tag Registers*/
+#define CANIDT  _SFR_MEM32(0xF0)
+
 #define CANIDT4 _SFR_MEM8(0xF0)
 #define RB0TAG 0
 #define RB1TAG 1
@@ -1093,6 +1100,9 @@
 #define IDT27 6
 #define IDT28 7
 
+/* RegDef:  CAN Identifier Mask Registers */
+#define CANIDM  _SFR_MEM32(0xF4)
+
 #define CANIDM4 _SFR_MEM8(0xF4)
 #define IDEMSK 0
 #define RTRMSK 2
