@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iom32u4.h,v 1.1.2.11 2009/02/11 18:05:28 arcanum Exp $ */
+/* $Id: iom32u4.h 2185 2010-09-22 07:06:35Z aboyapati $ */
 
 /* avr/iom32u4.h - definitions for ATmega32U4. */
 
@@ -540,7 +540,10 @@
 
 #define TIMSK5 _SFR_MEM8(0x73)
 
+#ifndef _ASSEMBLER_
 #define ADC _SFR_MEM16(0x78)
+#endif
+#define ADCW _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -576,7 +579,7 @@
 #define ADTS0 0
 #define ADTS1 1
 #define ADTS2 2
-#define ADTS3 4
+#define ADTS3 3
 #define MUX5 5
 #define ACME 6
 #define ADHSM 7
