@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom6450.h,v 1.11.2.2 2008/01/06 20:10:45 arcanum Exp $ */
+/* $Id: iom6450.h 2115 2010-04-05 23:19:53Z arcanum $ */
 
 /* avr/iom6450.h - definitions for ATmega6450 */
 
@@ -778,11 +778,11 @@
 
 /* Timer/Counter1 Compare Match A */
 #define TIMER1_COMPA_vect		_VECTOR(7)
-#define SIG_OUTPUT_COMPARE1A		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE1A	_VECTOR(7)
 
 /* Timer/Counter Compare Match B */
 #define TIMER1_COMPB_vect		_VECTOR(8)
-#define SIG_OUTPUT_COMPARE1B		_VECTOR(8)
+#define SIG_OUTPUT_COMPARE1B	_VECTOR(8)
 
 /* Timer/Counter1 Overflow */
 #define TIMER1_OVF_vect			_VECTOR(9)
@@ -798,18 +798,21 @@
 
 /* SPI Serial Transfer Complete */
 #define SPI_STC_vect			_VECTOR(12)
-#define SIG_SPI				_VECTOR(12)
+#define SIG_SPI				    _VECTOR(12)
 
 /* USART, Rx Complete */
 #define USART_RX_vect			_VECTOR(13)
+#define USART0_RX_vect			_VECTOR(13)  /* Alias */
 #define SIG_UART_RECV			_VECTOR(13)
 
 /* USART Data register Empty */
 #define USART_UDRE_vect			_VECTOR(14)
+#define USART0_UDRE_vect		_VECTOR(14)  /* Alias */
 #define SIG_UART_DATA			_VECTOR(14)
 
 /* USART0, Tx Complete */
 #define USART0_TX_vect			_VECTOR(15)
+#define USART_TX_vect			_VECTOR(15)  /* Alias */
 #define SIG_UART_TRANS			_VECTOR(15)
 
 /* USI Start Condition */
@@ -848,11 +851,13 @@
 
 
 /* Constants */
-#define SPM_PAGESIZE    256
-#define RAMEND          0x10FF
-#define XRAMEND         0x10FF
-#define E2END           0x7FF
-#define FLASHEND        0xFFFF
+#define SPM_PAGESIZE 256
+#define RAMSTART     (0x100)
+#define RAMEND       0x10FF
+#define XRAMEND      RAMEND
+#define E2END        0x7FF
+#define E2PAGESIZE   8
+#define FLASHEND     0xFFFF
 
 
 /* Fuses */
@@ -860,31 +865,31 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define FUSE_CKSEL0      ~_BV(0)
-#define FUSE_CKSEL1      ~_BV(1)
-#define FUSE_CKSEL2      ~_BV(2)
-#define FUSE_CKSEL3      ~_BV(3)
-#define FUSE_SUT0        ~_BV(4)
-#define FUSE_SUT1        ~_BV(5)
-#define FUSE_CKOUT       ~_BV(6)
-#define FUSE_CKDIV8      ~_BV(7)
+#define FUSE_CKSEL0      (unsigned char)~_BV(0)
+#define FUSE_CKSEL1      (unsigned char)~_BV(1)
+#define FUSE_CKSEL2      (unsigned char)~_BV(2)
+#define FUSE_CKSEL3      (unsigned char)~_BV(3)
+#define FUSE_SUT0        (unsigned char)~_BV(4)
+#define FUSE_SUT1        (unsigned char)~_BV(5)
+#define FUSE_CKOUT       (unsigned char)~_BV(6)
+#define FUSE_CKDIV8      (unsigned char)~_BV(7)
 #define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define FUSE_BOOTRST     ~_BV(0)
-#define FUSE_BOOTSZ0     ~_BV(1)
-#define FUSE_BOOTSZ1     ~_BV(2)
-#define FUSE_EESAVE      ~_BV(3)
-#define FUSE_WDTON       ~_BV(4)
-#define FUSE_SPIEN       ~_BV(5)
-#define FUSE_JTAGEN      ~_BV(6)
-#define FUSE_OCDEN       ~_BV(7)
+#define FUSE_BOOTRST     (unsigned char)~_BV(0)
+#define FUSE_BOOTSZ0     (unsigned char)~_BV(1)
+#define FUSE_BOOTSZ1     (unsigned char)~_BV(2)
+#define FUSE_EESAVE      (unsigned char)~_BV(3)
+#define FUSE_WDTON       (unsigned char)~_BV(4)
+#define FUSE_SPIEN       (unsigned char)~_BV(5)
+#define FUSE_JTAGEN      (unsigned char)~_BV(6)
+#define FUSE_OCDEN       (unsigned char)~_BV(7)
 #define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN & FUSE_JTAGEN)
 
 /* Extended Fuse Byte */
-#define FUSE_RSTDISBL    ~_BV(0)
-#define FUSE_BODLEVEL0   ~_BV(1)
-#define FUSE_BODLEVEL1   ~_BV(2)
+#define FUSE_RSTDISBL    (unsigned char)~_BV(0)
+#define FUSE_BODLEVEL0   (unsigned char)~_BV(1)
+#define FUSE_BODLEVEL1   (unsigned char)~_BV(2)
 #define EFUSE_DEFAULT (0xFF)
 
 
@@ -894,4 +899,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x96
+#define SIGNATURE_2 0x06
+
+
 #endif /* _AVR_IOM6450_H_ */
